@@ -67,7 +67,7 @@ def diff_columns(source: obj.Table, target: obj.Table) -> t.List[str]:
 
     for col_name in target_unique:
         col = helpers.get_column(target, col_name)
-        rv.append(helpers.make_column_add(col))
+        rv.append("ADD COLUMN %s" % helpers.make_column(col))
     return rv
 
 
@@ -274,12 +274,16 @@ def diff_tables(source: obj.Database, target: obj.Database) -> t.List[str]:
 
 
 def diff(source: obj.Database, target: obj.Database) -> t.List[str]:
+    statements = []
+    statements.extend(diff_tables(source, target))
+    statements.extend(diff_views(source, target))
+    statements.extend(diff_indices(source, target))
+    statements.extend(diff_sequences(source, target))
+    statements.extend(diff_enums(source, target))
+    statements.extend(diff_functions(source, target))
+    statements.extend(diff_triggers(source, target))
+
     rv = []
-    rv.extend(diff_tables(source, target))
-    rv.extend(diff_views(source, target))
-    rv.extend(diff_indices(source, target))
-    rv.extend(diff_sequences(source, target))
-    rv.extend(diff_enums(source, target))
-    rv.extend(diff_functions(source, target))
-    rv.extend(diff_triggers(source, target))
+    for s in statements:
+        rv.append(helpers.format_statement(s))
     return rv
